import { __rest } from "tslib";
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import React from "react";
import { Avatar, Box, Flex, Text, Icon, Stack, Center } from "@chakra-ui/react";
import { Link, useParams } from "react-router-dom";
import { RuntimeContext } from "../RuntimeContext";
import iconsList from "../components/iconsList";
import { useComposer } from "../Composer";
import Scrollbars from "rc-scrollbars";
import { getThemes } from "../registeredThemes";
import Tree, { mutateTree } from "@atlaskit/tree";
import { css } from "@emotion/react";
export const RenderItem = ({ item, navigations, provided, onCollapse, onExpand, params, composer, }) => {
    const isParent = React.useMemo(() => navigations.items[item.id].children.length > 0, [item, navigations]);
    return (_jsxs(Flex, Object.assign({ alignItems: "center", bg: "white", borderRadius: "md", py: "2", px: "2", bgColor: params.page === item.data.page ? "qore.primary" : "gray.50", transition: "opacity 200ms ease-out" }, provided.draggableProps, { children: [_jsx(Link, Object.assign({ to: (isParent && item.data.linked) || !isParent
                    ? `/page/${item.data.page}`
                    : "", onClick: () => composer.setExitDirection("none"), css: css `
          flex: 1;
        ` }, { children: _jsxs(Flex, Object.assign({ gap: "2", pl: "4", w: "full", cursor: "pointer", justifyContent: "left", alignItems: "center" }, { children: [_jsx(Icon, { color: params.page === item.data.page ? "white" : "text.900", as: iconsList[item.data.icon] }), _jsx(Text, Object.assign({ color: params.page === item.data.page ? "white" : "text.900" }, { children: item.data.label }))] })) })), _jsx(Center, { children: item.children && item.children.length > 0 && (_jsx(Icon, { boxSize: 5, color: params.page === item.data.page ? "white" : "text.900", as: iconsList["ChevronDown"], onClick: () => item.isExpanded ? onCollapse(item.id) : onExpand(item.id), transition: "all 200ms ease-out", transform: `rotate(${item.isExpanded ? 0 : -90}deg)`, cursor: "pointer" })) })] })));
};
const SidebarLayout = ({ children, page }) => {
    var _a;
    const appName = RuntimeContext.useSelectState((state) => state.app.name);
    const appIcon = RuntimeContext.useSelectState((state) => state.app.icon);
    const runtimeActions = RuntimeContext.useActions();
    const params = useParams();
    const composer = useComposer();
    const appTheme = RuntimeContext.useSelectState((state) => state.app.theme);
    const theme = (_a = getThemes().find((theme) => theme.id === appTheme.id)) === null || _a === void 0 ? void 0 : _a.theme;
    const renderThumb = React.useCallback((_a) => {
        var { style } = _a, props = __rest(_a, ["style"]);
        return (_jsx("div", Object.assign({ style: Object.assign(Object.assign({}, style), { backgroundColor: theme.colors.text["900"] }) }, props)));
    }, [theme]);
    const collapsible = RuntimeContext.useSelectState((state) => state.app.navbar.sidetop.collapsible);
    const navigations = RuntimeContext.useSelectState((state) => state.app.navbar.sidetop.content);
    const onExpand = React.useCallback((itemId) => {
        const newTree = mutateTree(navigations, itemId, { isExpanded: true });
        runtimeActions.swapSidetopNavContent(newTree);
    }, [runtimeActions, navigations]);
    const onCollapse = React.useCallback((itemId) => {
        const newTree = mutateTree(navigations, itemId, { isExpanded: false });
        runtimeActions.swapSidetopNavContent(newTree);
    }, [runtimeActions, navigations]);
    return (_jsxs(Box, Object.assign({ textColor: "text.900" }, { children: [page.navbar.sidetop.show && (_jsx(Box, Object.assign({ display: {
                    base: "none",
                    md: "initial",
                }, overflowY: "hidden", position: "absolute", height: "100%", maxWidth: { md: "30%", lg: "250px" }, top: "0", left: "0", right: "0", bg: "surface.800", borderRight: "1px solid", borderColor: "bg.900" }, { children: _jsx(Scrollbars, Object.assign({ renderThumbVertical: renderThumb, autoHide: true }, { children: _jsx(Flex, Object.assign({ alignItems: "center", h: "56px", bg: "qore.primary" }, { children: _jsxs(Box, Object.assign({ display: { base: "none", md: "initial" }, w: "100%", h: "100%", minH: "100%" }, { children: [_jsx(Box, Object.assign({ bg: "surface.900" }, { children: _jsxs(Flex, Object.assign({ alignItems: "center", h: "56px", padding: "16px", gap: "2" }, { children: [_jsx(Avatar, { size: "md", name: appName, src: appIcon, loading: "eager", bg: "bg.900", ignoreFallback: true }), _jsx(Text, Object.assign({ fontWeight: "bold", fontSize: "lg", noOfLines: 1, pr: 4, color: "text.900" }, { children: appName || "Menu" }))] })) })), _jsx(Box, { children: _jsx(Stack, Object.assign({ direction: "column", spacing: 0, py: 2, display: navigations.items.root.children.length > 0
                                            ? "initial"
                                            : "none" }, { children: _jsx(Flex, Object.assign({ direction: "column", borderRadius: "md", py: navigations.items.root.children.length > 0 ? 2 : 0, px: "4", css: css `
                          > div {
                            display: flex;
                            flex-direction: column;
                            gap: 8px;
                          }
                        ` }, { children: _jsx(Tree, { tree: navigations, renderItem: (e) => (_jsx(RenderItem, { item: e.item, navigations: navigations, provided: e.provided, onCollapse: onCollapse, onExpand: onExpand, params: params, composer: composer })), offsetPerLevel: 20, isNestingEnabled: true }) })) })) })] })) })) })) }))), _jsx(Box, Object.assign({ position: "absolute", left: {
                    base: 0,
                    md: !page.navbar.sidetop.show || collapsible ? 0 : "30%",
                    lg: !page.navbar.sidetop.show || collapsible ? 0 : "250px",
                }, right: "0", top: "0", bottom: "0", overflow: "hidden" }, { children: children }))] })));
};
export default SidebarLayout;
//# sourceMappingURL=SidebarLayout.js.map